@@ -135,6 +135,12 @@ class BaseHistogramModel(BaseEstimator):
                 "Input data must be a pandas Series, DataFrame, or numpy ndarray."
             )
 
+    def _get_index(self, X: Union[pd.Series, List[np.ndarray], List[list]]):
+        """
+        Helper function to retrieve the index of a pandas Series or generate a default index.
+        """
+        return X.index if hasattr(X, "index") else list(range(len(X)))
+
     def _compute_outlier_score(self, X: np.ndarray, i: int) -> np.ndarray:
         """
         Calculates the self-information (surprisal) outlier score for each value in a specified feature column.
@@ -193,8 +199,8 @@ class BaseHistogramModel(BaseEstimator):
 
         if self.decision_scores_ is None:
             raise ValueError("Model must be fitted before prediction.")
-
+        index = self._get_index(X)
         X = check_array(X)
         scores = self.decision_function(X)
         threshold = np.quantile(self.decision_scores_, quantile, method="higher")
-        return scores > threshold
+        return pd.Series(scores > threshold, index=index)
